@@ -1,22 +1,24 @@
 from bs4 import BeautifulSoup
-from tghtml import tghtml
+from tghtml import TgHTML
 
 from .aioget import aioget
 
 
 async def page(name):
     text = await aioget(f"https://memepedia.ru/{name}/")
-    parsed = tghtml(text, [
+    parsed = TgHTML(text, [
         ["section"],
         ["ul"], ["ol"], ["li"],
         ["div", {"class": "mistape_caption"}]
-    ])
+    ]).parsed
 
     soup = BeautifulSoup(text, "lxml")
 
     try:
-        image = soup.find_all("figure", {"class": "s-post-media-img"})[0].img["src"]
+        image = soup.find_all("figure", {
+            "class": "s-post-media-img"
+        })[0].img["src"]
     except IndexError:
         image = ""
 
-    return [image, parsed.replace("•", "")]
+    return [image, parsed.replace("•", "").replace("\n", "\n\n")]
